# License

The code in this directory is [Mortal](https://github.com/Equim-chan/Mortal)'s libriichi with minor updates. Mortal is distributed under the [AGPL-3.0](https://github.com/Equim-chan/Mortal/blob/main/LICENSE) and is copyrighted by [Equim](https://github.com/Equim-chan).

Copyright (C) 2021-2022 Equim